from sqlalchemy import pool
from validador_colab.infra.configs import CONFIGS
import psycopg2
import os
import sshtunnel


class DBConnectionHandlerPostgresControle:

    @staticmethod
    def getconn_colab():
        c = psycopg2.connect(
            user=CONFIGS.COLAB_PROD_USERNAME,
            password=CONFIGS.COLAB_PROD_PASSWORD,
            host=CONFIGS.COLAB_PROD_HOST,
            database=CONFIGS.COLAB_PROD_NAME,
            port=CONFIGS.COLAB_PROD_PORT
        )
        return c

    def __init__(self):
        pool_colab = pool.QueuePool(
            self.getconn_colab, max_overflow=0, pool_size=2)
        self.conn_colab = pool_colab.connect()
        self.cursor_colab = self.conn_colab.cursor()

    def insert(self, sql, mode='COLAB'):
        if mode.upper() == "COLAB":
            try:
                self.cursor_colab.execute(sql)
            except Exception as e:
                print(e)
                self.cursor_colab.execute('rollback')
            finally:
                self.cursor_colab.execute('commit')



from validador_colab.infra.repositories import SmarketAnalyticsRepositoryPostgres
from validador_colab.core.usecases import SmarketService
from validador_colab.infra.routes import daily_conf_router
from validador_colab.infra.routes import daily_conf_tasks
from fastapi import FastAPI, Depends
import asyncio

app = FastAPI()

app.include_router(daily_conf_router)

# TODO: Apagar temp_data automaticamente
# TODO: Implementar entrada data/industria
# TODO: Documentar API
# TODO: Rota que gera relatório


if __name__ == "__main__":
    import uvicorn
    uvicorn.run("main:app", host="0.0.0.0", port=8000, reload=True)



from validador_colab.core.entities import ColabCounter
from validador_colab.core.repositories import ColabCountersRepository
from validador_colab.core.errors import NoDataFound
from datetime import datetime


class ColabService:

    def __init__(self, colab_counters_repository: ColabCountersRepository):
        self.colab_counters_repository = colab_counters_repository

    def get_colab_counters(self, industry_id, date_start: str = None, date_end: str = None):
        colab_counters = []
        if date_start is None and date_end is None:
            date_start = datetime.now().strftime("%Y-%m-%d")
            date_end = datetime.now().strftime("%Y-%m-%d")
        else:
            date_start = datetime.strptime(date_start, "%Y-%m-%d").strftime("%Y-%m-%d")
            date_end = datetime.strptime(date_end, "%Y-%m-%d").strftime("%Y-%m-%d")

        data = self.colab_counters_repository.get_data(industry_id, date_start, date_end)
        if len(data) > 0:
            for unit in data:
                colab_counters.append(ColabCounter(unit[0], unit[1], unit[2], unit[3]))
            return colab_counters
        else:
            print(f"Sem dados para a industria {industry_id}, na data {date_start} até {date_end}")
            raise NoDataFound



from fastapi import APIRouter,Depends, HTTPException
from starlette.responses import RedirectResponse
from validador_colab.loop import first_block
import asyncio
import datetime

router = APIRouter(
    prefix="/daily_conf",
    tags=["daily_conf"],
    responses={404: {"status": "404", "description": "Not found"}},
)

fut = None
tasks = []


async def calculate_daily_conf(fut, industry_id: int = None, date_start: str = None, date_end: str = None):
    count_produtos_certos, count_produtos_errados = await first_block(industry_id, date_start, date_end)
    fut.set_result((count_produtos_certos, count_produtos_errados))


@router.get("/calculate/{industry_id}")
async def calculate(industry_id: int, date_start: str = None, date_end: str = None):
    global fut
    loop = asyncio.get_event_loop()
    fut = loop.create_future()
    loop.create_task(calculate_daily_conf(fut, industry_id, date_start, date_end))
    return {"status": "calculating"}


@router.get("/{industry_id}")
async def get_daily_conf(industry_id: int, date_start: str = None, date_end: str = None):

    if date_start is None or date_end is None:
        date_start = datetime.datetime.now().strftime("%Y-%m-%d")
        date_end = datetime.datetime.now().strftime("%Y-%m-%d")

    global fut

    if fut:
        await fut
    else:
        return RedirectResponse(url=f'/daily_conf/calculate/{industry_id}?date_start={date_start}&date_end={date_end}')
    count_produtos_certos, count_produtos_errados = fut.result()

    passing_conditions = True

    if count_produtos_certos == 0:
        passing_conditions = False
    if count_produtos_errados > 0:
        passing_conditions = False

    fut = None

    if not passing_conditions:
        return {"data": {"condition": "fail"}}
    else:
        return {"data": {"condition": "pass"}}






class ColabCounter:

    def __init__(self, seqproduto: int, date: str,
                 id_cliente: int, qtd_fatcupom: int):

        self.seqproduto = seqproduto
        self.date = date
        self.id_cliente = id_cliente
        self.qtd_fatcupom = qtd_fatcupom



from validador_colab.core.repositories import ColabCountersRepository
from validador_colab.infra.database import DBConnectionHandlerPostgres
from validador_colab.infra.configs import CONFIGS


class ColabCountersRepositoryPostgres(ColabCountersRepository):

        def get_data(self, industry_id, date_start, date_end):

            cadastro = ''

            if industry_id == 11:
                cadastro = 'produto_natural_one'
            elif industry_id == 13:
                cadastro = 'produto_sakura'

            sql = f"""
            with cte_produto as (
                select distinct
                    dp.seq_produto,
                    dic.id_cliente
                from cadastro.{cadastro} pno
                join dw.dim_produto dp on ( array[pno.ean] <@ dp.eans )
                join dw.dim_industria_cliente dic on (dp.id_cliente = dic.id_cliente)
                join dw.dim_industria di on (dic.id_industria = di.id_industria)
                where dic.id_industria = {industry_id}
            ),
            cte_fatcupom as (
            SELECT
                            dp.seq_produto as seq_produto,
                            fc.dt_venda as dt_venda,
                            fc.id_cliente as id_cliente,
                            sum(fc.qtd_produto) as qtd_fatcupom,
                            max(fc.dt_hr_carga) as dt_hr_carga
            from cte_produto cp
            join dw.dim_produto dp on (cp.seq_produto,cp.id_cliente) = (dp.seq_produto,dp.id_cliente)
            join dw.fat_cupom fc on dp.id_produto = fc.id_produto
            where fc.dt_venda between '{date_start}' and '{date_end}'
            group by dp.seq_produto, fc.dt_venda,fc.id_cliente
            )
            select distinct
                            cfc.seq_produto as seq_produto,
                            cfc.dt_venda as dt_venda,
                            cfc.id_cliente as id_cliente,
                            cfc.qtd_fatcupom
            from cte_fatcupom cfc
            order by cfc.dt_venda, cfc.id_cliente, cfc.seq_produto;
            """

            CONFIGS.COLAB_DB = 'dw'
            db = DBConnectionHandlerPostgres()
            data = db.get('COLAB', sql)

            return data



from validador_colab.core.repositories import SmarketAnalyticsRepository
from validador_colab.infra.configs import CONFIGS
from validador_colab.infra.database import DBConnectionHandlerPostgres


def client(client_id):
    if client_id == 20:
        return 'IMPERATRIZ'
    elif client_id == 30:
        return 'SUPERNOSSO'
    elif client_id == 70:
        return 'BRASILATACADISTA'


class SmarketAnalyticsRepositoryPostgres(SmarketAnalyticsRepository):

    def get_data(self, industry, date_start: str, date_end: str, client_id: int = None):

        sql = f"""
        with cte_produto as (
        select 	cast(sp.seqproduto as int) seqproduto,
                sp.descricao,
                spe.ean,
                sf.seqfornecedor,
                sf.fornecedor
        from smarket_produto sp
        join smarket_produto_ean spe on spe.seqproduto=sp.seqproduto
        join smarket_fornecedor sf on sf.seqfornecedor=sp.seqfornecedor
        where cast(sp.seqproduto as int) in ({','.join([str(x) for x in industry.products])}) /*NATURAL ONE*/
        ),
        cte_analytics as (
        SELECT dt,
               cast(seqproduto as int) seqproduto,
               sum(quantidade) analytics
        from public.smarket_analytics sa
        where dt between '{date_start}' and '{date_end}'
        group by 1, 2
        order by 1, 3
        )
        select
                ca.seqproduto,
                ca.dt,
                cp.descricao,
                cp.ean,
                ca.analytics
        from cte_analytics ca
        join cte_produto cp on cp.seqproduto=ca.seqproduto
        order by dt, seqproduto
        """

        data = []

        CONFIGS.CLIENT_ID = f"db_{client(client_id).lower()}"
        db = DBConnectionHandlerPostgres()
        data.extend(db.get('SMARKET', sql))

        return data



class DivergentData(Exception):

    def __init__(self, seqproduto, date):
        self.message = f"Dados divergentes para o seqproduto: {seqproduto} na data: {date}"
        super().__init__(self.message)



import os
from functools import lru_cache
import dotenv


class Configs:

    def __init__(self):

        dotenv.load_dotenv()
        self.SMARKET_PROD_HOST = os.getenv('SMARKET_PROD_HOST', 'rds-smarket-next-pg.cf6ldthil3ep.sa-east-1.rds.amazonaws.com')
        self.SMARKET_PROD_PORT = os.getenv('SMARKET_PROD_PORT', '5432')
        self.SMARKET_PROD_NAME = os.getenv('SMARKET_PROD_NAME', 'db_supernosso')
        self.SMARKET_PROD_USERNAME = os.getenv('SMARKET_PROD_USERNAME', 'davi_araujo')
        self.SMARKET_PROD_PASSWORD = os.getenv('SMARKET_PROD_PASSWORD', 'DVAJPG@2021*')
        self.COLAB_PROD_HOST = os.getenv('COLAB_PROD_HOST')
        self.COLAB_PROD_PORT = os.getenv('COLAB_PROD_PORT')
        self.COLAB_PROD_NAME = os.getenv('COLAB_PROD_NAME')
        self.COLAB_PROD_USERNAME = os.getenv('COLAB_PROD_USERNAME')
        self.COLAB_PROD_PASSWORD = os.getenv('COLAB_PROD_PASSWORD')
        self.CLIENT_ID = ''
        self.COLAB_DB = 'dw'
        self.MODE = 'DEV'


@lru_cache()
def get_configs():
    return Configs()



class SmarketCounter:

    def __init__(self, seqproduto: int, date: str,
                 description: str, ean: str, analytics: int,
                 client_id: int):

        self.seqproduto = seqproduto
        self.date = date
        self.description = description
        self.ean = ean
        self.analytics = analytics
        self.client_id = client_id

    



from validador_colab.infra.repositories import SmarketAnalyticsRepositoryPostgres, ColabCountersRepositoryPostgres
from validador_colab.core.usecases import SmarketService, ColabService
from validador_colab.core.entities import Sakura, NaturalOne, ValidationDetail
from validador_colab.core.errors import NoDataFound
from validador_colab.infra.database import DBConnectionHandlerPostgres, DBConnectionHandlerPostgresControle
import pickle
import os
import asyncio
import datetime

temp_data_folder = os.path.join(os.getcwd(), 'temp_data')

db = DBConnectionHandlerPostgresControle()


async def first_block(industry_id: int, date_start, date_end, print_corretos=True):
    if not os.path.exists(temp_data_folder):
        os.makedirs(temp_data_folder)

    if industry_id == 11: #Natural One
        industry = NaturalOne()
    elif industry_id == 13: #Sakura
        industry = Sakura()

    pickle_colab_name = "colab_data_" + industry.__repr__() + "_" + date_start + "_" + date_end + ".pkl"
    pickle_smarket_name = "smarket_data_" + industry.__repr__() + "_" + date_start + "_" + date_end + ".pkl"

    try:
        if not os.path.exists(os.path.join(temp_data_folder, pickle_smarket_name)):
            print("Getting data from smarket")
            smarket_data = SmarketService(SmarketAnalyticsRepositoryPostgres()).get_smarket_counters(industry, date_start, date_end)
            with open(os.path.join(temp_data_folder, pickle_smarket_name), 'wb') as f:
                pickle.dump(smarket_data, f)
            print("Data saved")
        else:
            print("Loading data from smarket")
            with open(os.path.join(temp_data_folder, pickle_smarket_name), 'rb') as f:
                smarket_data = pickle.load(f)
            print("Data loaded")

        if not os.path.exists(os.path.join(temp_data_folder, pickle_colab_name)):
            print("Getting data from colab")
            colab_data = ColabService(ColabCountersRepositoryPostgres()).get_colab_counters(industry_id, date_start, date_end)
            with open(os.path.join(temp_data_folder, pickle_colab_name), 'wb') as f:
                pickle.dump(colab_data, f)
            print("Data saved")
        else:
            print("Loading data from colab")
            with open(os.path.join(temp_data_folder, pickle_colab_name), 'rb') as f:
                colab_data = pickle.load(f)
            print("Data loaded")
    except NoDataFound:
        print(f"Sem dados cadastrados para a industria no dia {date_start} até o dia {date_end}")

    #esta merda aqui vai ficar troncha, loop dentro de loop, mas é o que tem pra hoje
    print('Iniciando processamento')
    count_produtos_certos = {}
    count_produtos_errados = {}
    validation_intel = []


    # Primeira validação: Se o produto está com os quantitativos iguais na fat_cupom e no Analytics
    for colab_unit in colab_data:
        for smarket_unit in smarket_data:
            if colab_unit.id_cliente == smarket_unit.client_id:
                if colab_unit.date == smarket_unit.date:
                    if int(colab_unit.seqproduto) == int(smarket_unit.seqproduto):
                        if int(colab_unit.qtd_fatcupom) == int(smarket_unit.analytics):
                            if print_corretos:
                                print('-------------------')
                                print(f'Cliente {smarket_unit.client_id}')
                                print(f"Data {smarket_unit.date}")
                                print(f'Tudo certo no produto: {smarket_unit.seqproduto} - {smarket_unit.description}')
                                print(f'Quantitativo no analytics: {smarket_unit.analytics}')
                                print(f'Quantitativo na fatcupom colab: {colab_unit.qtd_fatcupom}')
                                print('-------------------')
                            if smarket_unit.client_id not in count_produtos_certos:
                                count_produtos_certos[smarket_unit.client_id] = {}

                            if smarket_unit.date not in count_produtos_certos[smarket_unit.client_id]:
                                count_produtos_certos[smarket_unit.client_id][smarket_unit.date] = 0

                            count_produtos_certos[smarket_unit.client_id][smarket_unit.date] += 1

                        else:
                            print('-------------------')
                            print(f'Cliente {smarket_unit.client_id}')
                            print(f"Data {smarket_unit.date}")
                            print(f'ERRO no produto: {smarket_unit.seqproduto} - {smarket_unit.description}')
                            print(f'Quantitativo no analytics: {smarket_unit.analytics}')
                            print(f'Quantitativo na fatcupom colab: {colab_unit.qtd_fatcupom}')
                            print('-------------------')
                            if smarket_unit.client_id not in count_produtos_errados:
                                count_produtos_errados[smarket_unit.client_id] = {}

                            if smarket_unit.date not in count_produtos_errados[smarket_unit.client_id]:
                                count_produtos_errados[smarket_unit.client_id][smarket_unit.date] = 0

                            count_produtos_errados[smarket_unit.client_id][smarket_unit.date] += 1

    # Segunda validação - Produtos presentes nas tabelas:
    prod_cliente_data = {}
    colab_cliente_data = {}
    produtos_ausentes_analytics = {}
    produtos_ausentes_colab = {}
    datas_para_nao_subir = {}

    for colab_unit in colab_data:
        if colab_unit.id_cliente not in colab_cliente_data:
            colab_cliente_data[colab_unit.id_cliente] = {}
        if colab_unit.date not in colab_cliente_data[colab_unit.id_cliente]:
            colab_cliente_data[colab_unit.id_cliente][colab_unit.date] = []
        if colab_unit.seqproduto not in colab_cliente_data[colab_unit.id_cliente][colab_unit.date]:
            colab_cliente_data[colab_unit.id_cliente][colab_unit.date].append(colab_unit.seqproduto)

    for smarket_unit in smarket_data:
        if smarket_unit.client_id not in prod_cliente_data:
            prod_cliente_data[smarket_unit.client_id] = {}
        if smarket_unit.date not in prod_cliente_data[smarket_unit.client_id]:
            prod_cliente_data[smarket_unit.client_id][smarket_unit.date] = []
        if smarket_unit.seqproduto not in prod_cliente_data[smarket_unit.client_id][smarket_unit.date]:
            prod_cliente_data[smarket_unit.client_id][smarket_unit.date].append(smarket_unit.seqproduto)

    #Gerador produtos ausentes colab
    for client_id, date_counter in prod_cliente_data.items():
        for date, prod_list in date_counter.items():
            for prod in prod_list:
                if client_id in colab_cliente_data:
                    if date in colab_cliente_data[client_id]:
                        if prod not in colab_cliente_data[client_id][date]:
                            if client_id not in produtos_ausentes_colab:
                                produtos_ausentes_colab[client_id] = {}
                            if date not in produtos_ausentes_colab[client_id]:
                                produtos_ausentes_colab[client_id][date] = []
                            print(f"Produto {prod} não encontrado na base do colab para cliente: {client_id} na data: {date}")
                            produtos_ausentes_colab[client_id][date].append(prod)
                    else:
                        print(f"Data: {date} não encontrada na base do colab para cliente: {client_id}")
                        if client_id not in datas_para_nao_subir:
                            datas_para_nao_subir[client_id] = []
                        if date not in datas_para_nao_subir[client_id]:
                            validation_intel.append(ValidationDetail(
                                exec_date=datetime.datetime.now().strftime("%Y-%m-%d %H:%M:%S"),
                                industry_id=industry_id,
                                client_id=client_id,
                                sale_date=date,
                                validation_status=False
                            ))
                            datas_para_nao_subir[client_id].append(date)

                        break

                else:
                    print(f"Cliente não encontrado na base do colab para industria: {industry_id}")

        # Gerador produtos ausentes analitycs
        for client_id, date_counter in colab_cliente_data.items():
            for date, prod_list in date_counter.items():
                for prod in prod_list:
                    if client_id in prod_cliente_data:
                        if date in prod_cliente_data[client_id]:
                            if prod not in prod_cliente_data[client_id][date]:
                                if client_id not in produtos_ausentes_analytics:
                                    produtos_ausentes_analytics[client_id] = {}
                                if date not in produtos_ausentes_analytics[client_id]:
                                    produtos_ausentes_analytics[client_id][date] = []
                                produtos_ausentes_analytics[client_id][date].append(prod)
                                print(f"Produto {prod} não encontrado na base do analytics para cliente: {client_id} na data: {date}")

                        else:
                            print(f"Data: {date} não encontrada na base do analytics para cliente: {client_id}")
                            if client_id not in datas_para_nao_subir:
                                datas_para_nao_subir[client_id] = []
                            if date not in datas_para_nao_subir[client_id]:
                                validation_intel.append(ValidationDetail(
                                    exec_date=datetime.datetime.now().strftime("%Y-%m-%d %H:%M:%S"),
                                    industry_id=industry_id,
                                    client_id=client_id,
                                    sale_date=date,
                                    validation_status=False
                                ))
                                datas_para_nao_subir[client_id].append(date)
                            break

                    else:
                        print(f"Cliente não encontrado na base do colab para industria: {industry_id}")

    # Geração da primeira tabela com base nos valores errados
    if len(count_produtos_errados) > 0:
        for client_id, counter in count_produtos_errados.items():
            for date, count in counter.items():
                if client_id in datas_para_nao_subir:
                    if date.strftime("%Y-%m-%d") not in [x.strftime("%Y-%m-%d") for x in datas_para_nao_subir[client_id]]:
                        if count > 0:
                            validation_intel.append(
                                ValidationDetail(
                                    exec_date=datetime.datetime.now().strftime("%Y-%m-%d %H:%M:%S"),
                                    industry_id=industry_id,
                                    client_id=client_id,
                                    sale_date=date,
                                    validation_status=False
                                )
                            )
                        else:
                            validation_intel.append(
                                ValidationDetail(
                                    exec_date=datetime.datetime.now().strftime("%Y-%m-%d %H:%M:%S"),
                                    industry_id=industry_id,
                                    client_id=client_id,
                                    sale_date=date,
                                    validation_status=True
                                )
                            )


    if len(count_produtos_certos) > 0 and len(count_produtos_errados) == 0:
        for client_id, counter in count_produtos_certos.items():
            for date, count in counter.items():
                if client_id in datas_para_nao_subir:
                    if date.strftime("%Y-%m-%d") not in [x.strftime("%Y-%m-%d") for x in datas_para_nao_subir[client_id]]:
                        if count > 0:
                            validation_intel.append(
                                ValidationDetail(
                                    exec_date=datetime.datetime.now().strftime("%Y-%m-%d %H:%M:%S"),
                                    industry_id=industry_id,
                                    client_id=client_id,
                                    sale_date=date,
                                    validation_status=True
                                )
                            )
                else:
                    validation_intel.append(
                        ValidationDetail(
                            exec_date=datetime.datetime.now().strftime("%Y-%m-%d %H:%M:%S"),
                            industry_id=industry_id,
                            client_id=client_id,
                            sale_date=date,
                            validation_status=True
                        )
                    )

    # Inserindo os dados no banco de validation:
    sql_insert = """INSERT INTO
        PUBLIC.CONTROLE(id_industria, id_cliente, dt_venda, status_validacao)
        VALUES
    """
    for validation in validation_intel:
        sql_insert += f"""({int(validation.industry_id)}, {int(validation.client_id)}, '{validation.sale_date}', {bool(validation.validation_status)}),"""

    sql_insert = sql_insert[:-1]
    print(sql_insert)

    db.insert(sql_insert)



if __name__ == "__main__":
    asyncio.run(first_block(11, '2023-06-05', '2023-06-05', True))



class ValidationDetail:

    def __init__(self, exec_date, industry_id, client_id, sale_date, validation_status):
        self.exec_date = exec_date
        self.industry_id = industry_id
        self.client_id = client_id
        self.sale_date = sale_date
        self.validation_status = validation_status




from sqlalchemy import pool
from validador_colab.infra.configs import CONFIGS
import psycopg2
import os
import sshtunnel


class DBConnectionHandlerPostgres:

    # def start_smarket_tunnel(self):
    #     """Somente utilizar em caso de dev"""
    #     self.ssh_tunnel = sshtunnel.SSHTunnelForwarder(
    #         ('20.0.1.66', 22),
    #         ssh_username='davi_araujo',
    #         ssh_pkey=os.path.join('home', 'davi', '.ssh', 'id_ed25519'),
    #         ssh_private_key_password='',
    #         remote_bind_address=('20.0.1.66', 22)
    #     )
    #
    #     self.ssh_tunnel.start()
    #
    # def stop_smarket_tunnel(self):
    #     "Implementar para fazer este treco parar de rodar no final da execução"
    #     self.ssh_tunnel.stop()

    @staticmethod
    def getconn_colab():
        c = psycopg2.connect(
            user=CONFIGS.COLAB_PROD_USERNAME,
            password=CONFIGS.COLAB_PROD_PASSWORD,
            host=CONFIGS.COLAB_PROD_HOST,
            database=CONFIGS.COLAB_PROD_NAME,
            port=CONFIGS.COLAB_PROD_PORT
        )
        return c

    @staticmethod
    def getconn_smarket():
        c = psycopg2.connect(
            user=CONFIGS.SMARKET_PROD_USERNAME,
            password=CONFIGS.SMARKET_PROD_PASSWORD,
            host=CONFIGS.SMARKET_PROD_HOST,
            port=CONFIGS.COLAB_PROD_PORT,
            database=CONFIGS.CLIENT_ID)
        return c

    def __init__(self):
        # self.ssh_tunnel = None
        # if CONFIGS.MODE == 'DEV':
        #     self.start_smarket_tunnel()

        pool_colab = pool.QueuePool(
            self.getconn_colab, max_overflow=0, pool_size=2)
        pool_smarket = pool.QueuePool(
            self.getconn_smarket, max_overflow=0, pool_size=2)
        self.conn_colab = pool_colab.connect()
        self.conn_smarket = pool_smarket.connect()
        self.cursor_colab = self.conn_colab.cursor()
        self.cursor_smarket = self.conn_smarket.cursor()

    def get(self, mode: str, sql: str):

        values = [()]

        if mode.upper() == 'COLAB':
            self.cursor_colab.execute(sql)
            try:
                values = self.cursor_colab.fetchall()
            except Exception as e:
                self.cursor_colab.execute('rollback')
            finally:
                self.cursor_colab.execute('commit')
            return values

        elif mode.upper() == 'SMARKET':
            self.cursor_smarket.execute(sql)
            try:
                values = self.cursor_smarket.fetchall()
            except Exception as e:
                self.cursor_smarket.execute('rollback')
            finally:
                self.cursor_smarket.execute('commit')
            return values

    def insert(self, sql, mode='COLAB'):
        if mode.upper() == "COLAB":
            try:
                self.cursor_colab.execute(sql)
            except Exception as e:
                self.cursor_colab.execute('rollback')
            finally:
                self.cursor_colab.execute('commit')



if __name__ == "__main__":

    db = DBConnectionHandlerPostgres()
    print(db.get('smarket', 'select now();'))
    #db.stop_smarket_tunnel()
    print(db.get('smarket', 'select now();'))



from validador_colab.core.entities import SmarketCounter
from validador_colab.core.repositories import SmarketAnalyticsRepository
from validador_colab.core.errors import NoDataFound
from datetime import datetime


class SmarketService:

    def __init__(self, smarket_analytics_repository: SmarketAnalyticsRepository):
        self.smarket_analytics_repository = smarket_analytics_repository

    def get_smarket_counters(self, industry, date_start: str = None, date_end: str = None):
        smarket_counters = []
        if date_start is None or date_end is None:
            date_start = datetime.now().strftime("%Y-%m-%d")
            date_end = datetime.now().strftime("%Y-%m-%d")
        else:
            date_start = datetime.strptime(date_start, "%Y-%m-%d").strftime("%Y-%m-%d")
            date_end = datetime.strptime(date_end, "%Y-%m-%d").strftime("%Y-%m-%d")
        #data = []
        for client_id in industry.clients:
            data = self.smarket_analytics_repository.get_data(industry, date_start, date_end, client_id)
            if len(data) > 0:
                for unit in data:
                    smarket_counters.append(SmarketCounter(unit[0], unit[1], unit[2], unit[3], unit[4], client_id))
        return smarket_counters


